@@ -10,7 +10,7 @@
 #include <jni.h>
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
-#include <libgtk-java/jg_jnu.h>
+#include "jg_jnu.h"
 
 #ifndef _Included_org_gnu_gconf_ConfClient
 #define _Included_org_gnu_gconf_ConfClient
@@ -106,7 +106,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gconf_ConfClient_gconf_1client_1notify_1add
 	NotifyData *data;
 	guint ret;
 	if (methodID == NULL) {
-		methodID = (*env)->GetMethodID(env, cls, "notifyCallback", "(Lorg/gnu/glib/Handle;Ljava/lang/String;)V");
+		methodID = (*env)->GetMethodID(env, cls, "notifyCallback", "(ILjava/lang/String;)V");
 		if (methodID == NULL)
 			return -1;
 	}
